@@ -1,13 +1,12 @@
 treePValues <- function(tree, abundances, environments){
 
   igraphTree <- graph.edgelist(tree)
-  
+
   treePValues <- vector(length = length(V(igraphTree)))
   names(treePValues) <- V(igraphTree)$name
-  head(treePValues)
 
   for(vertex in V(igraphTree)){
-    
+
     ## first, aggregate data descending ##
     ## from that node ##
     graphDiameter <- diameter(igraphTree)
@@ -22,13 +21,13 @@ treePValues <- function(tree, abundances, environments){
 
     if(length(namesInTipsIndex) > 0){
 
-      subOtuTable <- abundances[V(subtree)$name[namesInTipsIndex], ]
+      subOtuTable <- abundances[V(subtree)$name[namesInTipsIndex], , drop=F]
       aggregateData <- colSums(subOtuTable)
       aggregateDataWithLabel <- data.frame(abund = as.vector(aggregateData),
                                            type = environments)
-      
+
       ## fit the LM to obtain p-values ##
-      
+
       abundanceModel <- summary(lm(abund ~ type, data = aggregateDataWithLabel))
       treePValues[curVertexName] <- pf(abundanceModel$fstatistic[1],
                                        abundanceModel$fstatistic[2],
